### Name: mcmcFmodel
### Title: Inference in a spatial statistical model
### Aliases: mcmcFmodel


### ** Examples

  # Below is a complete sequence 
  # of commands using Geneland functions

  # we assume that Geneland is installed
  # and loaded by library("Geneland")


  #  first look for a place to write
  #  simulated data and MCMC outputs
if(.Platform$OS == "unix"){
repdat = "/tmp/"
repmcmc= "/tmp/"
}

if(.Platform$OS == "windows"){
repdat = "/temp/"
repmcmc= "/temp/"
}

 # Simulation of a dataset made of 2 populations
 # 2 loci and 2 alleles per locus
simFmodel(nindiv=100,
          slim=c(0,1,0,1),
          npp=2,
          nloc=5,
          nall=c(5,5,5,5,5),
          nclass=2,
          drift=c(.3,.3),
          plots=FALSE,
          ploth=FALSE,
          seed=12345,
          write=TRUE,
          repout=repdat)

  # First run of MCMC algorithm
  # in order to get the posterior mode of the number of populations
mcmcFmodel(repdat=repdat,
           repmcmc=repmcmc,
           lambdamax=100,
           dt=0,
           nclassmin=1,
           nclassinit=5,
           nclassmax=10,
           nppmax=200,
           nchain=5000,
           stepw=10,
           model="Dirichlet",
           varnclass=TRUE,
           spatial=TRUE)

 # Trace of number of populations
 # Should display a mode at 2
Plotnclass(repdat,repmcmc)

 # Then re-run the chain with fixed number of populations
mcmcFmodel(repdat=repdat,
           repmcmc=repmcmc,
           lambdamax=100,
           dt=0,
           nclassmin=1,
           nclassinit=2,
           nclassmax=2,
           nppmax=200,
           nchain=5000,
           stepw=10,
           model="Dirichlet",
           varnclass=FALSE,
           spatial=TRUE)

  # Post-processing the chain 
PostProcessChain(repdat=repdat,
                 repmcmc=repmcmc,
                 nxdom=50,
                 nydom=50,
                 burnin=0)

  # Plots allele frequencies of allele #1 at locus  #1 in sub-population  #1
PlotFreq(repdat=repdat,repmcmc=repmcmc,ipop=1,iloc=1,iall=1)

  # Map of posterior probabilites
  # of population membership
PlotTessellation(repdat=repdat,repmcmc=repmcmc)

  # Map of posterior mode 
  # of population membership
PosteriorMode(repdat=repdat,repmcmc=repmcmc,
              write=FALSE,plotit=TRUE)






